package handler

import (
	"errors"
	"fmt"
	"net/http"

	"github.com/zeromicro/go-zero/core/logx"
	"github.com/zeromicro/go-zero/rest/httpx"

	"fusenapi/server/home-user-auth/internal/logic"
	"fusenapi/server/home-user-auth/internal/svc"
	"fusenapi/server/home-user-auth/internal/types"
	"fusenapi/utils/basic"
)

func UserLoginHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.RequestUserLogin
		if err := httpx.Parse(r, &req); err != nil {
			httpx.OkJsonCtx(r.Context(), w, &types.Response{
				Code:    510,
				Message: "parameter error",
			})
			logx.Info(err)
			return
		}

		l := logic.NewUserLoginLogic(r.Context(), svcCtx)
		resp, token := l.UserLogin(&req)
		if resp.Code == basic.CodeOK.Code {
			w.Header().Add("Authorization", fmt.Sprintf("Bearer %s", token))
		}
		if resp != nil {
			httpx.OkJsonCtx(r.Context(), w, resp)
		} else {
			err := errors.New("server logic is error, resp must not be nil")
			httpx.ErrorCtx(r.Context(), w, err)
			logx.Error(err)
		}
	}
}
